@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 8
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20180726
+#define __GLIBCXX__ 20200304
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -609,6 +609,11 @@ namespace std
 # endif
 #endif
 
+/* Define if __float128 is supported on this host. */
+#if defined(__FLOAT128__) || defined(__SIZEOF_FLOAT128__)
+#undef _GLIBCXX_USE_FLOAT128
+#endif
+
 // End of prewritten config; the settings discovered at configure time follow.
 /* config.h.  Generated from config.h.in by configure.  */
 /* config.h.in.  Generated from configure.ac by autoheader.  */
@@ -1374,6 +1379,9 @@ namespace std
 /* Version number of package */
 /* #undef _GLIBCXX_VERSION */
 
+/* Number of bits in a file offset, on hosts where this is settable. */
+/* #undef _GLIBCXX_FILE_OFFSET_BITS */
+
 /* Define if C99 functions in <complex.h> should be used in <complex> for
    C++11. Using compiler builtins for these functions requires corresponding
    C99 library functions to be present. */
@@ -1530,9 +1538,6 @@ namespace std
 /* Define if fchmodat is available in <sys/stat.h>. */
 /* #undef _GLIBCXX_USE_FCHMODAT */
 
-/* Define if __float128 is supported on this host. */
-/* #undef _GLIBCXX_USE_FLOAT128 */
-
 /* Defined if gettimeofday is available. */
 #define _GLIBCXX_USE_GETTIMEOFDAY 1
 
@@ -1604,6 +1609,9 @@ namespace std
 /* Define to 1 if mutex_timedlock is available. */
 #define _GTHREAD_USE_MUTEX_TIMEDLOCK 1
 
+/* Define for large files, on AIX-style hosts. */
+/* #undef _GLIBCXX_LARGE_FILES */
+
 /* Define if all C++11 floating point overloads are available in <math.h>.  */
 #if __cplusplus >= 201103L
 /* #undef __CORRECT_ISO_CPP11_MATH_H_PROTO_FP */
